@@ -2,7 +2,7 @@ from ._table import add_table, get_table, TableWidget
 from ._regionprops import regionprops, regionprops_table, regionprops_table_all_frames
 from ._multichannel import link_two_label_images, measure_labels, measure_labels_with_intensity
 from ._multichannel import measure_labels_in_labels_with_intensity, measure_labels_in_labels
-from ._multichannel import regionprops_measure_things_inside_things
+from ._multichannel import regionprops_measure_relationship_to_other_channels
 from ._process_tables import merge_measurements_to_reference, make_summary_table
 from ._parametric_images import visualize_measurement_on_labels, relabel, map_measurements_on_labels
 from ._measure_points import measure_points
@@ -12,7 +12,7 @@ from ._load_csv import load_csv
 try:
     from ._version import version as __version__
 except ImportError:
-    __version__ = "0.9.0"
+    __version__ = "0.10.0"
 
 
 @napari_hook_implementation
