@@ -1,12 +1,6 @@
-import pandas
-import numpy as np
 from typing import List
 from magicgui import magic_factory
 from napari_tools_menu import register_dock_widget
-from ._regionprops import regionprops_table
-from ._process_tables import merge_measurements_to_reference
-from ._process_tables import make_summary_table
-
 
 
 def make_element_wise_dict(list_of_keys, list_of_values):
@@ -32,21 +26,21 @@ def make_element_wise_dict(list_of_keys, list_of_values):
 def _connect_events(widget):
     def toggle_intensity_widgets(event):
         widget.intensity_image_reference.visible = event
-        # If things_inside_things is True when enabling intensity, then enable
+        # If relate_to_other_channels is True when enabling intensity, then enable
         # intensity image inputs
-        if (event == True) & (widget.things_inside_things.value == True):
-            widget.intensity_images_to_measure.visible = True
+        if (event == True) & (widget.relate_to_other_channels.value == True):
+            widget.intensity_images_other_channels.visible = True
         else:
-            widget.intensity_images_to_measure.visible = False
+            widget.intensity_images_other_channels.visible = False
 
-    def toggle_things_inside_things_widgets(event):
-        widget.label_images_to_measure.visible = event
-        widget.intersection_over_target_area.visible = event
+    def toggle_relate_to_other_channels_widgets(event):
+        widget.label_images_other_channels.visible = event
+        widget.intersection_over_target_obj_area.visible = event
         widget.configure_summary_statistics.visible = event
         if (event == True) & (widget.intensity.value == True):
-            widget.intensity_images_to_measure.visible = True
+            widget.intensity_images_other_channels.visible = True
         else:
-            widget.intensity_images_to_measure.visible = False
+            widget.intensity_images_other_channels.visible = False
         if event == True:
             if widget.configure_summary_statistics.value == True:
                 toggle_summary_statistics_widgets(True)
@@ -65,17 +59,17 @@ def _connect_events(widget):
         widget.maximum.visible = event
 
     widget.intensity.changed.connect(toggle_intensity_widgets)
-    widget.things_inside_things.changed.connect(toggle_things_inside_things_widgets)
+    widget.relate_to_other_channels.changed.connect(toggle_relate_to_other_channels_widgets)
     widget.configure_summary_statistics.changed.connect(
         toggle_summary_statistics_widgets
         )
 
     # Intial visibility states
     widget.intensity_image_reference.visible = False
-    widget.intensity_images_to_measure.visible = False
-    widget.label_images_to_measure.visible = False
+    widget.intensity_images_other_channels.visible = False
+    widget.label_images_other_channels.visible = False
     widget.configure_summary_statistics.visible = False
-    widget.intersection_over_target_area.visible = False
+    widget.intersection_over_target_obj_area.visible = False
     widget.counts.visible = False
     widget.average.visible = False
     widget.std.visible = False
@@ -93,16 +87,16 @@ widgets_layout_settings = {
     'intensity_image_reference': {
         'label': 'Intensity Image Reference'
     },
-    'label_images_to_measure': {
+    'label_images_other_channels': {
         'label': 'Label Image(s) from other Channel(s)'
     },
-    'intensity_images_to_measure': {
+    'intensity_images_other_channels': {
         'label': 'Intensity Image(s) from other Channel(s)'
     },
-    'things_inside_things': {
+    'relate_to_other_channels': {
         'label': 'relate to other channel(s)'
     },
-    'intersection_over_target_area': {
+    'intersection_over_target_obj_area': {
         'widget_type': 'FloatSlider',
         'min': 0,
         'max': 1,
@@ -134,30 +128,30 @@ widgets_layout_settings = {
                    'label_image_reference'],
                intensity_image_reference=widgets_layout_settings[
                    'intensity_image_reference'],
-               label_images_to_measure=widgets_layout_settings[
-                   'label_images_to_measure'],
-               intensity_images_to_measure=widgets_layout_settings[
-                   'intensity_images_to_measure'],
-               intersection_over_target_area=widgets_layout_settings[
-                   'intersection_over_target_area'],
-               things_inside_things=widgets_layout_settings[
-                   'things_inside_things'],
+               label_images_other_channels=widgets_layout_settings[
+                   'label_images_other_channels'],
+               intensity_images_other_channels=widgets_layout_settings[
+                   'intensity_images_other_channels'],
+               intersection_over_target_obj_area=widgets_layout_settings[
+                   'intersection_over_target_obj_area'],
+               relate_to_other_channels=widgets_layout_settings[
+                   'relate_to_other_channels'],
                std=widgets_layout_settings['std'],
                percentile_25=widgets_layout_settings['percentile_25'],
                percentile_75=widgets_layout_settings['percentile_75'])
-def regionprops_measure_things_inside_things(
+def regionprops_measure_relationship_to_other_channels(
         label_image_reference: "napari.types.LabelsData",
         intensity_image_reference: "napari.types.ImageData",
-        label_images_to_measure: List["napari.types.LabelsData"],
-        intensity_images_to_measure: List["napari.types.ImageData"],
+        label_images_other_channels: List["napari.types.LabelsData"],
+        intensity_images_other_channels: List["napari.types.ImageData"],
         intensity: bool = False,
-        things_inside_things: bool = False,
+        relate_to_other_channels: bool = False,
         size: bool = True,
         perimeter: bool = False,
         shape: bool = False,
         position: bool = False,
         moments: bool = False,
-        intersection_over_target_area: float = 0.5,
+        intersection_over_target_obj_area: float = 0.5,
         configure_summary_statistics: bool = False,
         counts: bool = False,
         average: bool = True,
@@ -183,19 +177,19 @@ def regionprops_measure_things_inside_things(
         a label image used as a reference.
     intensity_image_reference : array_like
         an intensity image, matching the `label_image_reference` shape.
-    label_images_to_measure : List[array_like]
+    label_images_other_channels : List[array_like]
         a list of label images, whose measured features will be related to
         labels from `label_image_reference`.
-    intensity_images_to_measure : List[array_like]
+    intensity_images_other_channels : List[array_like]
         a list of label images, whose measured intensity features will be
         related to labels from `label_image_reference`.
     intensity : bool
         a flag indicating that intensity features should be measured. If
         `True`, `intensity_image_reference` must be given.
-    things_inside_things : bool
-        a flag indicating that things_inside_things analysis should be performed,
+    relate_to_other_channels : bool
+        a flag indicating that relate_to_other_channels analysis should be performed,
         relating labels from `label_image_reference` to
-        `label_images_to_measure`. If `True`, `label_images_to_measure`
+        `label_images_other_channels`. If `True`, `label_images_other_channels`
         must be provided.
     size : bool
         a flag indicating to measure size features. By default True.
@@ -207,7 +201,7 @@ def regionprops_measure_things_inside_things(
         a flag indicating to measure position features. By default False.
     moments : bool
         a flag indicating to measure moments features. By default False.
-    intersection_over_target_area : float
+    intersection_over_target_obj_area : float
         a ratio of areas that indicates whether an object is considered
         'inside' another. It is the intersection area divided by the target
         object area. It goes from 0 to 1. 0 indicates object always belongs to
@@ -250,7 +244,9 @@ def regionprops_measure_things_inside_things(
         in other channels.
     """
     from napari.utils import notifications
+    from ._process_tables import make_summary_table
     import napari
+    import numpy as np
 
     statistics_list = []
     if counts:
@@ -279,31 +275,31 @@ def regionprops_measure_things_inside_things(
                     reference_labels_layer = layer
                     reference_suffix = '_' + layer.name
         suffixes.insert(0, reference_suffix)
-        for i, labels in enumerate(label_images_to_measure):
+        for i, labels in enumerate(label_images_other_channels):
             for layer in napari_viewer.layers:
                 if isinstance(layer, napari.layers.Labels) and np.array_equal(layer.data, labels):
                     new_suffix = '_' + layer.name
                     if new_suffix not in suffixes:
                         suffixes.append(new_suffix)
                     else:
-                        # labels_to_measure layer is a duplicated reference
-                        n_leading_zeros = len(label_images_to_measure) // 10
+                        # label_image_other_channel layer is a duplicated reference
+                        n_leading_zeros = len(label_images_other_channels) // 10
                         suffixes.append(new_suffix + str(i+1).zfill(1+n_leading_zeros))
     # Ensures proper iterable inputs
     else:
-        if not isinstance(label_images_to_measure, list):
-            label_images_to_measure = [label_images_to_measure]
-        if not isinstance(intensity_images_to_measure, list):
-            intensity_images_to_measure = [intensity_images_to_measure]
+        if not isinstance(label_images_other_channels, list):
+            label_images_other_channels = [label_images_other_channels]
+        if not isinstance(intensity_images_other_channels, list):
+            intensity_images_other_channels = [intensity_images_other_channels]
         # in case function is used without viewer and suffixes are missing
         if len(suffixes) == 0:
-            n_leading_zeros = len(label_images_to_measure) // 10
+            n_leading_zeros = len(label_images_other_channels) // 10
             suffixes = ['_reference'] + ['_' + str(i+1).zfill(
                 1+n_leading_zeros)
-                for i in range(len(label_images_to_measure))]
+                for i in range(len(label_images_other_channels))]
 
     # Single image measurements
-    if things_inside_things == False:
+    if relate_to_other_channels == False:
         # Without intensity measurements
         if intensity == False:
             table = measure_labels(
@@ -331,8 +327,8 @@ def regionprops_measure_things_inside_things(
                 shape=shape, position=position,
                 moments=moments)
         else:
-            # Check if user provided 'label_images_to_measure'
-            if len(label_images_to_measure) == 0:
+            # Check if user provided 'label_images_other_channels'
+            if len(label_images_other_channels) == 0:
                 notifications.show_warning(('Error! Add a labels layer to '
                                             '\'Label Image(s) from other '
                                             'Channel(s)\' when \'relate '
@@ -344,19 +340,19 @@ def regionprops_measure_things_inside_things(
             if intensity == False:
                 table = measure_labels_in_labels(
                     label_image_reference=label_image_reference,
-                    labels_to_measure=label_images_to_measure,
+                    label_image_other_channel=label_images_other_channels,
                     size=size,
                     perimeter=perimeter,
                     shape=shape,
                     position=position,
                     moments=moments,
-                    intersection_over_target_area=intersection_over_target_area,
+                    intersection_over_target_obj_area=intersection_over_target_obj_area,
                     suffixes=suffixes)
 
             # Or with intensity measurements
             else:
-                # Check if user provided 'intensity_images_to_measure'
-                if len(intensity_images_to_measure) == 0:
+                # Check if user provided 'intensity_images_other_channels'
+                if len(intensity_images_other_channels) == 0:
                     notifications.show_warning(('Error! Add an image layer to '
                                             '\'Intensity Image(s) from other '
                                             'Channel(s)\' when both \'relate '
@@ -366,13 +362,13 @@ def regionprops_measure_things_inside_things(
                     return
                 table = measure_labels_in_labels_with_intensity(
                 label_image_reference=label_image_reference,
-                labels_to_measure=label_images_to_measure,
+                label_image_other_channel=label_images_other_channels,
                 intensity_image_reference=intensity_image_reference,
-                intensity_image_of_labels_to_measure=intensity_images_to_measure,
+                intensity_image_other_channel=intensity_images_other_channels,
                 size=size, perimeter=perimeter,
                 shape=shape, position=position,
                 moments=moments,
-                intersection_over_target_area=intersection_over_target_area,
+                intersection_over_target_obj_area=intersection_over_target_obj_area,
                 suffixes=suffixes)
             # Compute summary statistics instead of individual relationships
             # This guarantees no repeated numbers in the 'label' column
@@ -395,8 +391,8 @@ def regionprops_measure_things_inside_things(
 
 
 def link_two_label_images(label_image_reference: "napari.types.LabelsData",
-                          labels_to_measure: "napari.types.LabelsData",
-                          intersection_over_target_area: float = 0.5
+                          label_image_other_channel: "napari.types.LabelsData",
+                          intersection_over_target_obj_area: float = 0.5
                           ) -> "pandas.DataFrame":
     """
     Associate each label from a reference to a target label image.
@@ -410,14 +406,14 @@ def link_two_label_images(label_image_reference: "napari.types.LabelsData",
     ----------
     label_image_reference : napari.types.LabelsData
         a label image to be used as reference labels.
-    labels_to_measure : napari.types.LabelsData
+    label_image_other_channel : napari.types.LabelsData
         a label image to be used as target labels.
-    intersection_over_target_area : float, optional
+    intersection_over_target_obj_area : float, optional
         an area ratio threshold value that determines if a label in
         the target image belongs to another in the reference image.
         The area ratio is calculated by the intersection area divided
         by the target label area. If this area ratio is bigger
-        or equal to `intersection_over_target_area`, the target object
+        or equal to `intersection_over_target_obj_area`, the target object
         gets associated to the reference object, otherwise, it gets
         associated to the background. This parameter goes from 0 to 1,
         by default 0.5.
@@ -434,7 +430,7 @@ def link_two_label_images(label_image_reference: "napari.types.LabelsData",
     from skimage.measure import regionprops_table as sk_regionprops_table
 
     def highest_overlap(regionmask, label_image_reference,
-                        overlap_threshold=intersection_over_target_area):
+                        overlap_threshold=intersection_over_target_obj_area):
         """
         Get the label number with highest overlap with label in another image.
 
@@ -484,7 +480,7 @@ def link_two_label_images(label_image_reference: "napari.types.LabelsData",
 
     # Create table that links labels from scanning channel to reference channel
     table_linking_labels = pd.DataFrame(
-        sk_regionprops_table(label_image=np.asarray(labels_to_measure).astype(int),
+        sk_regionprops_table(label_image=np.asarray(label_image_other_channel).astype(int),
                              intensity_image=np.asarray(label_image_reference).astype(int),
                              properties=['label', ],
                              extra_properties=[highest_overlap]
@@ -554,6 +550,9 @@ def measure_labels(label_image_reference: "napari.types.LabelsData",
     pandas.DataFrame
         A table containing labels and corresponding measured features.
     """
+    from ._regionprops import regionprops_table
+    import numpy as np
+
     table = regionprops_table(image=np.zeros_like(label_image_reference),
                               labels=label_image_reference,
                               size=size,
@@ -609,6 +608,8 @@ def measure_labels_with_intensity(
     pandas.DataFrame
         A table containing labels and corresponding measured features.
     """
+    from ._regionprops import regionprops_table
+
     table = regionprops_table(image=intensity_image_reference,
                               labels=label_image_reference,
                               size=size,
@@ -621,13 +622,13 @@ def measure_labels_with_intensity(
 
 
 def measure_labels_in_labels(label_image_reference: "napari.types.LabelsData",
-                             labels_to_measure: List["napari.types.LabelsData"],
+                             label_image_other_channel: List["napari.types.LabelsData"],
                              size: bool = True,
                              perimeter: bool = False,
                              shape: bool = False,
                              position: bool = False,
                              moments: bool = False,
-                             intersection_over_target_area: float = 0.5,
+                             intersection_over_target_obj_area: float = 0.5,
                              suffixes: List[str] = None,
                              napari_viewer: "napari.Viewer" = None
                              ) -> List["pandas.DataFrame"]:
@@ -638,13 +639,13 @@ def measure_labels_in_labels(label_image_reference: "napari.types.LabelsData",
     one or more target label images. It returns a table
     where each column is a feature and each row associates
     a label (and its features) from `label_image_reference`
-    to a target label (and its features) from `labels_to_measure`.
+    to a target label (and its features) from `label_image_other_channel`.
 
     Parameters
     ----------
     label_image_reference : napari.types.LabelsData
         a reference label image to measure features.
-    labels_to_measure : List[napari.types.LabelsData]
+    label_image_other_channel : List[napari.types.LabelsData]
         a list of target label images to measure features.
     size : bool, optional
         measure size related features.
@@ -661,12 +662,12 @@ def measure_labels_in_labels(label_image_reference: "napari.types.LabelsData",
     moments : bool, optional
         measure moments related features.
         By default False.
-    intersection_over_target_area : float, optional
+    intersection_over_target_obj_area : float, optional
         an area ratio threshold value that determines if a label in
         the target image belongs to another in the reference image.
         The area ratio is calculated by the intersection area divided
         by the target label area. If this area ratio is bigger
-        or equal to `intersection_over_target_area`, the target object
+        or equal to `intersection_over_target_obj_area`, the target object
         gets associated to the reference object, otherwise, it gets
         associated to the background. This parameter goes from 0 to 1,
         by default 0.5.
@@ -683,6 +684,8 @@ def measure_labels_in_labels(label_image_reference: "napari.types.LabelsData",
         A list of tables containing labels and corresponding measured features.
         Each row associates reference label features to target label features.
     """
+    from ._process_tables import merge_measurements_to_reference
+
     # Get reference properties
     reference_labels_properties = measure_labels(
         label_image_reference=label_image_reference,
@@ -694,16 +697,16 @@ def measure_labels_in_labels(label_image_reference: "napari.types.LabelsData",
         napari_viewer=napari_viewer
         )
     list_table_linking_labels = []
-    list_table_labels_to_measure_properties = []
-    # Make labels_to_measure iterable
-    if not isinstance(labels_to_measure, list):
-        labels_to_measure = [labels_to_measure]
-    # Link each labels_to_measure image to reference and get their properties
-    for label_image in labels_to_measure:
+    list_table_other_channel_labels_properties = []
+    # Make label_image_other_channel iterable
+    if not isinstance(label_image_other_channel, list):
+        label_image_other_channel = [label_image_other_channel]
+    # Link each label_image_other_channel image to reference and get their properties
+    for label_image in label_image_other_channel:
         table_linking_labels = link_two_label_images(
             label_image_reference=label_image_reference,
-            labels_to_measure=label_image,
-            intersection_over_target_area=intersection_over_target_area
+            label_image_other_channel=label_image,
+            intersection_over_target_obj_area=intersection_over_target_obj_area
             )
         list_table_linking_labels.append(table_linking_labels)
 
@@ -716,7 +719,7 @@ def measure_labels_in_labels(label_image_reference: "napari.types.LabelsData",
             moments=moments,
             napari_viewer=napari_viewer
             )
-        list_table_labels_to_measure_properties.append(
+        list_table_other_channel_labels_properties.append(
             labels_to_measure_properties)
 
     # Merge each table with target label properties to table with reference
@@ -724,22 +727,22 @@ def measure_labels_in_labels(label_image_reference: "napari.types.LabelsData",
     table_list = merge_measurements_to_reference(
         table_reference_labels_properties=reference_labels_properties,
         table_linking_labels=list_table_linking_labels,
-        table_labels_to_measure_properties=list_table_labels_to_measure_properties,
+        table_other_channel_labels_properties=list_table_other_channel_labels_properties,
         suffixes=suffixes)
     return table_list
 
 
 def measure_labels_in_labels_with_intensity(
         label_image_reference: "napari.types.LabelsData",
-        labels_to_measure: List["napari.types.LabelsData"],
+        label_image_other_channel: List["napari.types.LabelsData"],
         intensity_image_reference: "napari.types.ImageData",
-        intensity_image_of_labels_to_measure: List["napari.types.ImageData"] = None,
+        intensity_image_other_channel: List["napari.types.ImageData"] = None,
         size: bool = True,
         perimeter: bool = False,
         shape: bool = False,
         position: bool = False,
         moments: bool = False,
-        intersection_over_target_area: float = 0.5,
+        intersection_over_target_obj_area: float = 0.5,
         suffixes: List[str] = None,
         napari_viewer: "napari.Viewer" = None) -> List["pandas.DataFrame"]:
     """
@@ -751,17 +754,17 @@ def measure_labels_in_labels_with_intensity(
     images. It returns a table
     where each column is a feature and each row associates
     a label (and its features) from `label_image_reference`
-    to a target label (and its features) from `labels_to_measure`.
+    to a target label (and its features) from `label_image_other_channel`.
 
     Parameters
     ----------
     label_image_reference : napari.types.LabelsData
         a reference label image to measure features.
-    labels_to_measure : List[napari.types.LabelsData], array_like
+    label_image_other_channel : List[napari.types.LabelsData], array_like
         a list of target label images to measure features.
     intensity_image_reference : napari.types.ImageData, array_like
         a reference intensity image to measure intensity features.
-    intensity_image_of_labels_to_measure : List[napari.types.ImageData],
+    intensity_image_other_channel : List[napari.types.ImageData],
     array_like, optional
         a list of target intensity images to measure intensity features.
         If None (default), intensity features are extracted from 
@@ -781,12 +784,12 @@ def measure_labels_in_labels_with_intensity(
     moments : bool, optional
         measure moments related features.
         By default False.
-    intersection_over_target_area : float, optional
+    intersection_over_target_obj_area : float, optional
         an area ratio threshold value that determines if a label in
         the target image belongs to another in the reference image.
         The area ratio is calculated by the intersection area divided
         by the target label area. If this area ratio is bigger
-        or equal to `intersection_over_target_area`, the target object
+        or equal to `intersection_over_target_obj_area`, the target object
         gets associated to the reference object, otherwise, it gets
         associated to the background. This parameter goes from 0 to 1,
         by default 0.5.
@@ -803,6 +806,8 @@ def measure_labels_in_labels_with_intensity(
         A list of tables containing labels and corresponding measured features.
         Each row associates reference label features to target label features.
     """
+    from ._process_tables import merge_measurements_to_reference
+
     # Get reference properties
     reference_labels_properties = measure_labels_with_intensity(
         label_image_reference=label_image_reference,
@@ -815,33 +820,33 @@ def measure_labels_in_labels_with_intensity(
         napari_viewer=napari_viewer
         )
     list_table_linking_labels = []
-    list_table_labels_to_measure_properties = []
-    # Make labels_to_measure iterable
-    if not isinstance(labels_to_measure, list):
-        labels_to_measure = [labels_to_measure]
-    # If no intensity_image_of_labels_to_measure provided, use reference
+    list_table_other_channel_labels_properties = []
+    # Make label_image_other_channel iterable
+    if not isinstance(label_image_other_channel, list):
+        label_image_other_channel = [label_image_other_channel]
+    # If no intensity_image_other_channel provided, use reference
     # intensity
-    if intensity_image_of_labels_to_measure is None:
-        intensity_image_of_labels_to_measure = [intensity_image_reference] * \
-            len(labels_to_measure)
-    # If intensity_image_of_labels_to_measure provided, check if sizes match
+    if intensity_image_other_channel is None:
+        intensity_image_other_channel = [intensity_image_reference] * \
+            len(label_image_other_channel)
+    # If intensity_image_other_channel provided, check if sizes match
     else:
-        # Make intensity_image_of_labels_to_measure iterable
-        if not isinstance(intensity_image_of_labels_to_measure, list):
-            intensity_image_of_labels_to_measure = \
-                [intensity_image_of_labels_to_measure]
-        if len(intensity_image_of_labels_to_measure) != len(labels_to_measure):
-            print(('Error! Length of intensity_image_of_labels_to_measure and'
-                   'labels_to_measure must match.'))
+        # Make intensity_image_other_channel iterable
+        if not isinstance(intensity_image_other_channel, list):
+            intensity_image_other_channel = \
+                [intensity_image_other_channel]
+        if len(intensity_image_other_channel) != len(label_image_other_channel):
+            print(('Error! Length of intensity_image_other_channel and'
+                   'label_image_other_channel must match.'))
             return
 
-    # Link each labels_to_measure image to reference and get their properties
+    # Link each label_image_other_channel image to reference and get their properties
     for label_image, intensity_image in zip(
-            labels_to_measure, intensity_image_of_labels_to_measure):
+            label_image_other_channel, intensity_image_other_channel):
         table_linking_labels = link_two_label_images(
             label_image_reference=label_image_reference,
-            labels_to_measure=label_image,
-            intersection_over_target_area=intersection_over_target_area
+            label_image_other_channel=label_image,
+            intersection_over_target_obj_area=intersection_over_target_obj_area
             )
         list_table_linking_labels.append(table_linking_labels)
 
@@ -855,7 +860,7 @@ def measure_labels_in_labels_with_intensity(
             moments=moments,
             napari_viewer=napari_viewer
             )
-        list_table_labels_to_measure_properties.append(
+        list_table_other_channel_labels_properties.append(
             labels_to_measure_properties)
 
     # Merge each table with target label properties to table with reference
@@ -863,6 +868,6 @@ def measure_labels_in_labels_with_intensity(
     table_list = merge_measurements_to_reference(
         table_reference_labels_properties=reference_labels_properties,
         table_linking_labels=list_table_linking_labels,
-        table_labels_to_measure_properties=list_table_labels_to_measure_properties,
+        table_other_channel_labels_properties=list_table_other_channel_labels_properties,
         suffixes=suffixes)
     return table_list
